@@ -23,7 +23,7 @@ __plugin_usage__ = '''俄罗斯轮盘帮助：
     开始对决：开枪（轮流开枪，30秒未开枪另一方可使用‘结算’命令结束对决并胜利）
     结算：结算（当某一方30秒未开枪，可使用该命令强行结束对决并胜利）
     我的战绩：我的战绩
-    排行榜：胜场排行/败场排行/欧洲人排行/慈善家排行
+    排行榜：金币排行/胜场排行/败场排行/欧洲人排行/慈善家排行
     【注：同一时间群内只能有一场对决】
 '''
 
@@ -300,7 +300,7 @@ async def _(bot: Bot, event: GroupMessageEvent, state: T_State):
             nickname = event.sender.card if event.sender.card else event.sender.nickname
             await shot.finish(random.choice([
                 f'不要打扰 {player1_name} 和 {player2_name} 的决斗啊！',
-                '给我好好做好一个观众！不然小真寻就要生气了',
+                '给我好好做好一个观众！不然list(bot.config.nickname)[0]就要生气了',
                 f'不要捣乱啊baka{nickname}！'
             ]), at_sender=True)
         nickname = player1_name if rs_player[event.group_id]["next"] == rs_player[event.group_id][1] else player2_name
